'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var CloseIcon = _interopDefault(require('@mui/icons-material/Close'));
var Box = _interopDefault(require('@mui/material/Box'));
var Fade = _interopDefault(require('@mui/material/Fade'));
var styles = require('@mui/material/styles');
var React = require('react');
var React__default = _interopDefault(React);
var MUITypography = _interopDefault(require('@mui/material/Typography'));
var useTheme = _interopDefault(require('@mui/system/useTheme'));
var MUIButton = _interopDefault(require('@mui/material/Button'));
var MUICard = _interopDefault(require('@mui/material/Card'));
var CardActionArea = _interopDefault(require('@mui/material/CardActionArea'));
var CardActions = _interopDefault(require('@mui/material/CardActions'));
var CardContent = _interopDefault(require('@mui/material/CardContent'));
var CardMedia = _interopDefault(require('@mui/material/CardMedia'));
var Paper = _interopDefault(require('@mui/material/Paper'));
var MuiTab = _interopDefault(require('@mui/material/Tab'));
var MuiTabs = _interopDefault(require('@mui/material/Tabs'));

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _taggedTemplateLiteralLoose(strings, raw) {
  if (!raw) {
    raw = strings.slice(0);
  }

  strings.raw = raw;
  return strings;
}

var bootstrapColors = ["primary", "secondary", "success", "danger", "warning", "info", "light", "dark"];
var bootstrapPalette = function bootstrapPalette(theme) {
  return {
    primary: {
      contrastText: theme.palette.primary.contrastText,
      main: theme.palette.primary.main
    },
    secondary: {
      contrastText: theme.palette.secondary.contrastText,
      main: theme.palette.secondary.main
    },
    success: {
      contrastText: "#fff",
      main: "#5cb85c"
    },
    danger: {
      contrastText: "#fff",
      main: "#d9534f"
    },
    warning: {
      contrastText: "#333",
      main: "#f0ad4e"
    },
    info: {
      contrastText: "#fff",
      main: "#5bc0de"
    },
    light: {
      contrastText: theme.palette.text.secondary,
      main: theme.palette.background.paper
    },
    dark: {
      contrastText: theme.palette.background.paper,
      main: theme.palette.text.primary
    }
  };
};

var Typography = /*#__PURE__*/React__default.forwardRef(function BootstrapButton(props, ref) {
  var color = props.color,
      otherProps = _objectWithoutPropertiesLoose(props, ["color"]);

  var theme = useTheme();
  var bootstrapColors = {
    primary: {
      color: theme.palette.primary.main
    },
    secondary: {
      color: theme.palette.secondary.main
    },
    success: {
      color: "#218838"
    },
    danger: {
      color: "#c82333"
    },
    warning: {
      color: "#e0a800"
    },
    info: {
      color: "#138496"
    },
    light: {
      color: theme.palette.text.secondary
    },
    dark: {
      color: theme.palette.text.primary
    }
  };
  var colorProp = color === "inherit" ? {
    color: undefined
  } : bootstrapColors[color === undefined ? "dark" : color];
  return React__default.createElement(MUITypography, Object.assign({}, otherProps, {
    sx: {
      color: colorProp,
      "& a": {
        color: colorProp.color,
        fontWeight: "bolder",
        textDecoration: "none",
        "&:hover": {
          textDecoration: "underline"
        }
      }
    },
    ref: ref
  }));
});

var _templateObject;
function bootstrapAlertStyles(color, theme) {
  var palette = bootstrapPalette(theme);
  var clr = color === "light" ? theme.palette.text.secondary : color === "dark" ? theme.palette.text.primary : palette[color].main;
  var borderColor = color === "light" || color === "dark" ? theme.palette.divider : styles.alpha(styles.lighten(clr, 0.6), 0.8);
  var backgroundColor = color === "light" ? styles.alpha(theme.palette.text.secondary, 0.035) : color === "dark" ? styles.alpha(theme.palette.text.primary, 0.95) : styles.alpha(styles.lighten(clr, 0.8), 0.95);
  var headerColor = color === "light" ? styles.alpha(theme.palette.text.primary, 0.9) : color === "dark" ? styles.alpha(theme.palette.background.paper, 0.9) : styles.darken(clr, 0.6);
  return {
    borderColor: borderColor,
    backgroundColor: backgroundColor,
    headerColor: headerColor
  };
}
/**
 * @deprecated MUI v5 has a better Alert component now!
 */

function Alert(props) {
  var _maxWidthClass, _maxWidthClass2, _maxWidthClass3, _maxWidthClass4, _maxWidthClass5;

  var theme = styles.useTheme();
  var htmlFontSize = theme.typography.htmlFontSize;
  var coef = theme.typography.fontSize / 14;

  var pxToRem = function pxToRem(size) {
    return size / htmlFontSize * coef + "rem";
  };

  var _bootstrapAlertStyles = bootstrapAlertStyles(props.color || "danger", theme),
      borderColor = _bootstrapAlertStyles.borderColor,
      backgroundColor = _bootstrapAlertStyles.backgroundColor,
      headerColor = _bootstrapAlertStyles.headerColor;

  var _React$useState = React__default.useState(true),
      show = _React$useState[0],
      setShow = _React$useState[1];

  React__default.useEffect(function () {
    if (props.show !== undefined) {
      setShow(props.show);
    }
  }, [props.show]);

  function handleDismiss() {
    setShow(false);

    if (props.onClose !== undefined) {
      props.onClose();
    }
  }

  var maxWidthClass;

  switch (props.maxWidth) {
    case "xl":
      maxWidthClass = (_maxWidthClass = {}, _maxWidthClass[theme.breakpoints.up("xl")] = {
        maxWidth: theme.breakpoints.values.xl
      }, _maxWidthClass);
      break;

    case "lg":
      maxWidthClass = (_maxWidthClass2 = {}, _maxWidthClass2[theme.breakpoints.up("lg")] = {
        maxWidth: theme.breakpoints.values.lg
      }, _maxWidthClass2);
      break;

    case "md":
      maxWidthClass = (_maxWidthClass3 = {}, _maxWidthClass3[theme.breakpoints.up("md")] = {
        maxWidth: theme.breakpoints.values.md
      }, _maxWidthClass3);
      break;

    case "sm":
      maxWidthClass = (_maxWidthClass4 = {}, _maxWidthClass4[theme.breakpoints.up("sm")] = {
        maxWidth: theme.breakpoints.values.sm
      }, _maxWidthClass4);
      break;

    case "xs":
      maxWidthClass = (_maxWidthClass5 = {}, _maxWidthClass5[theme.breakpoints.up("xs")] = {
        maxWidth: Math.max(theme.breakpoints.values.xs, 444)
      }, _maxWidthClass5);
      break;
  }

  return React__default.createElement(Fade, {
    "in": show,
    unmountOnExit: true
  }, React__default.createElement(Box, {
    sx: _extends({
      color: headerColor,
      backgroundColor: backgroundColor,
      borderColor: borderColor,
      position: "relative",
      border: "1px solid",
      padding: pxToRem(12) + " " + pxToRem(14),
      paddingRight: "" + pxToRem(28),
      borderRadius: pxToRem(4),
      "& a": {
        color: headerColor
      },
      "& p": {
        margin: 0
      }
    }, maxWidthClass)
  }, props.dismissible && React__default.createElement(CloseIcon, {
    onClick: handleDismiss,
    sx: {
      fontSize: pxToRem(18),
      right: 12,
      position: "absolute",
      cursor: "pointer",
      "&:hover": {
        color: "#333"
      }
    },
    color: "inherit"
  }), React__default.createElement(Typography, {
    color: "inherit"
  }, props.children)));
}
var StyledSpan = /*#__PURE__*/styles.styled("span")(_templateObject || (_templateObject = /*#__PURE__*/_taggedTemplateLiteralLoose([""])));

function Heading(props) {
  return React__default.createElement(Typography, {
    color: "inherit",
    variant: "h5",
    component: "h2"
  }, props.icon && React__default.createElement(StyledSpan, {
    sx: {
      marginRight: 10,
      verticalAlign: -6,
      "& > *:first-child": {
        fontSize: 32
      }
    }
  }, props.icon), props.children);
}

Alert.Heading = Heading;

/**
 * @deprecated MUI v5 Button supports success, error, info, and warning colors, you can style the rest in your theme.
 */

var Button = /*#__PURE__*/React__default.forwardRef(function BootstrapButton(props, ref) {
  //   const classes = useStyles(props)
  var uppercase = props.uppercase,
      boxShadow = props.boxShadow,
      otherProps = _objectWithoutPropertiesLoose(props, ["color", "uppercase", "boxShadow"]);

  var theme = styles.useTheme();

  var bootstrapColors = _extends({}, bootstrapPalette(theme));

  function getColor(x) {
    return bootstrapColors[x.color === undefined ? "dark" : x.color];
  }

  return React__default.createElement(MUIButton, Object.assign({}, otherProps, {
    sx: {
      textTransform: uppercase === true ? undefined : "none",
      boxShadow: boxShadow === true ? undefined : "none",
      "&.Mui-disabled": {
        opacity: 0.3
      },
      "&.MuiButton-contained": {
        color: getColor(props).contrastText,
        backgroundColor: getColor(props).main,
        "&:hover": {
          backgroundColor: styles.darken(getColor(props).main, 0.25)
        }
      },
      "&.MuiButton-outlined,&.MuiButton-text": {
        color: props.color === "light" ? getColor(props).contrastText : getColor(props).main,
        borderColor: props.color === "light" ? styles.alpha(styles.darken(getColor(props).main, 0.3), 0.3) : getColor(props).main,
        "&:hover": {
          backgroundColor: props.color === "light" ? styles.alpha(styles.lighten(getColor(props).contrastText, 0.2), 0.15) : styles.alpha(styles.lighten(getColor(props).main, 0.2), 0.15),
          borderColor: props.color === "light" ? styles.lighten(getColor(props).contrastText, 0.5) : styles.lighten(getColor(props).main, 0.5),
          color: props.color === "light" ? styles.lighten(getColor(props).contrastText, 0.3) : styles.lighten(getColor(props).main, 0.3)
        }
      },
      "&:hover": {
        boxShadow: "none"
      }
    },
    ref: ref
  }));
});
Button.defaultProps = {
  size: "medium",
  color: "dark"
};
Button.defaultProps = {
  uppercase: false,
  boxShadow: false
};

var Card = /*#__PURE__*/React__default.forwardRef(function BootstrapButton(props, ref) {
  var color = props.color,
      otherProps = _objectWithoutPropertiesLoose(props, ["color"]);

  var theme = styles.useTheme();
  var palette = bootstrapPalette(theme);
  var backgroundColor = styles.lighten(palette[color || "light"].main, 0.3);
  var foreColor = palette[color || "light"].contrastText;
  return React__default.createElement(MUICard, Object.assign({}, otherProps, {
    sx: {
      backgroundColor: backgroundColor,
      color: foreColor,
      "& a": {
        color: foreColor,
        fontWeight: "bolder",
        textDecoration: "none",
        "&:hover": {
          textDecoration: "underline"
        }
      }
    },
    ref: ref,
    variant: "outlined"
  }));
});
function CardHeader(props) {
  var theme = styles.useTheme();
  return React__default.createElement(Box, {
    sx: {
      padding: "10px 14px 10px 14px",
      backgroundColor: styles.alpha("#000", 0.1),
      borderBottom: "1px solid " + theme.palette.divider
    }
  }, React__default.createElement(Typography, {
    color: "inherit"
  }, props.children));
}
function CardTitle(props) {
  return React__default.createElement(Typography, {
    color: "inherit",
    variant: "h5",
    component: "h2"
  }, props.children);
}

var _templateObject$1;
var StyledSpan$1 = /*#__PURE__*/styles.styled("span")(_templateObject$1 || (_templateObject$1 = /*#__PURE__*/_taggedTemplateLiteralLoose([""])));
function Label(props) {
  var theme = styles.useTheme();
  var palette = bootstrapPalette(theme);
  var foreColor = palette[props.color].contrastText;
  var backgroundColor = props.color === "light" ? styles.alpha(theme.palette.text.secondary, 0.1) : props.color === "dark" ? styles.alpha(theme.palette.text.primary, 0.85) : palette[props.color].main;
  return React__default.createElement(StyledSpan$1, {
    sx: {
      display: "inline-block",
      padding: ".2em .4em",
      borderRadius: ".35rem",
      color: foreColor,
      backgroundColor: backgroundColor
    }
  }, props.children);
}

var PanelContext = /*#__PURE__*/React__default.createContext("primary");
function Panel(props) {
  var theme = styles.useTheme();

  var _bootstrapAlertStyles = bootstrapAlertStyles(props.color, theme),
      borderColor = _bootstrapAlertStyles.borderColor;

  return React__default.createElement(Box, {
    sx: {
      overflow: "hidden",
      borderRadius: 1,
      border: "1px solid " + borderColor,
      backgroundColor: theme.palette.background.paper
    }
  }, React__default.createElement(PanelContext.Provider, {
    value: props.color
  }, props.children));
}
function PanelHeader(props) {
  var color = React.useContext(PanelContext);
  var theme = styles.useTheme();

  var _bootstrapAlertStyles2 = bootstrapAlertStyles(color, theme),
      borderColor = _bootstrapAlertStyles2.borderColor,
      backgroundColor = _bootstrapAlertStyles2.backgroundColor,
      headerColor = _bootstrapAlertStyles2.headerColor;

  return React__default.createElement(Box, {
    sx: {
      borderBottom: "1px solid " + borderColor,
      backgroundColor: backgroundColor,
      color: headerColor,
      padding: "10px 15px"
    }
  }, props.children);
}
function PanelBody(props) {
  return React__default.createElement(Box, {
    padding: 2
  }, props.children);
}

var Tabs = /*#__PURE__*/React.forwardRef(function (_ref, ref) {
  var tabs = _ref.tabs,
      children = _ref.children,
      selectedIndex = _ref.selectedIndex,
      onSelect = _ref.onSelect,
      props = _objectWithoutPropertiesLoose(_ref, ["tabs", "children", "selectedIndex", "onSelect"]);

  var theme = styles.useTheme();
  return React.createElement(React.Fragment, null, React.createElement(MuiTabs, Object.assign({
    ref: ref
  }, props, {
    value: selectedIndex,
    onChange: function onChange(_e, value) {
      return onSelect(value);
    },
    sx: {
      marginBottom: "-1px",
      "& .MuiTabs-scroller": {
        overflow: "visible !important"
      },
      "& .MuiTabs-indicator": {
        display: "none"
      }
    }
  }), tabs.map(function (tab) {
    if (typeof tab === "string") {
      return {
        label: tab
      };
    }

    return tab;
  }).map(function (tab, index) {
    return React.createElement(MuiTab, Object.assign({
      key: index
    }, tab, {
      value: index,
      sx: {
        textTransform: "none",
        borderLeft: "1px solid " + styles.alpha(theme.palette.divider, 0),
        borderRight: "1px solid " + styles.alpha(theme.palette.divider, 0),
        borderTop: "1px solid " + styles.alpha(theme.palette.divider, 0),
        color: theme.palette.primary.main,
        borderTopLeftRadius: 6,
        borderTopRightRadius: 6,
        ":hover": {
          borderLeft: "1px solid " + styles.alpha(theme.palette.primary.main, 0.25),
          borderRight: "1px solid " + styles.alpha(theme.palette.primary.main, 0.25),
          borderTop: "1px solid " + styles.alpha(theme.palette.primary.main, 0.25)
        },
        "&.Mui-selected": {
          color: theme.palette.text.secondary,
          backgroundColor: theme.palette.background.paper,
          borderLeft: "1px solid " + theme.palette.divider,
          borderRight: "1px solid " + theme.palette.divider,
          borderTop: "1px solid " + theme.palette.divider
        }
      }
    }));
  })), React.createElement(Paper, {
    variant: "outlined",
    sx: {
      padding: 3,
      borderTopLeftRadius: selectedIndex === 0 ? 0 : undefined
    }
  }, children));
});

exports.CardActionArea = CardActionArea;
exports.CardActions = CardActions;
exports.CardContent = CardContent;
exports.CardMedia = CardMedia;
exports.Alert = Alert;
exports.Button = Button;
exports.Card = Card;
exports.CardHeader = CardHeader;
exports.CardTitle = CardTitle;
exports.Label = Label;
exports.Panel = Panel;
exports.PanelBody = PanelBody;
exports.PanelHeader = PanelHeader;
exports.Tabs = Tabs;
exports.Typography = Typography;
exports.bootstrapColors = bootstrapColors;
exports.bootstrapPalette = bootstrapPalette;
//# sourceMappingURL=material-ui-bootstrap.cjs.development.js.map
